<?php
// $Id: views_system.views.inc,v 1.1.4.5 2010/11/04 14:15:32 flanker Exp $

/**
 * @file
 * Views data and handlers for the views_system module.
 */


/**
 * @defgroup views_system_module views_system.module handlers
 *
 * @{
 */


/**
 * Implementation of hook_views_data().
 */
function views_system_views_data() {

  $data = array();
  $data['system']['table'] = array(
    'base' => array(
      'title' => t('System item'),
      'help' => t("System items are modules, themes, and theme engines that are or have been installed in Drupal's file system."),
      'field' => 'filename',
      'weight' => 25,
    ),
    'group' => t('System'),
  );
  $data['system']['filename'] = array(
    'title' => t('Filename'),
    'help' => t('The path of the primary file for this item, relative to the Drupal root; e.g. modules/node/node.module.'),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_string',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['system']['name'] = array(
    'title' => t('Name'),
    'help' => t('The name of the item; e.g. node.'),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_string',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_string',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['system']['type'] = array(
    'title' => t('Type'),
    'help' => t('The type of the item, either module, theme, or theme_engine.'),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_string',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_in_operator',
      'options callback' => '_views_system_get_type',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['system']['owner'] = array(
    'title' => t('Owner'),
    'help' => t("A theme's 'parent'. Can be either a theme or an engine."),
    'field' => array(
      'handler' => 'views_handler_field',
      'click sortable' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_string',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_string',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['system']['status'] = array(
    'title' => t('Status'),
    'help' => t('Boolean indicating whether or not this item is enabled.'),
    'field' => array(
      'handler' => 'views_handler_field_boolean',
      'click sortable' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_numeric',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_system_status',
      'label' => t('Status'),
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['system']['throttle'] = array(
    'title' => t('Throttle'),
    'help' => t('Boolean indicating whether this item is disabled when the throttle.module disables throttleable items.'),
    'field' => array(
      'handler' => 'views_handler_field_boolean',
      'click sortable' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_numeric',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_boolean_operator',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['system']['bootstrap'] = array(
    'title' => t('Bootstrap'),
    'help' => t("Boolean indicating whether this module is loaded during Drupal's early bootstrapping phase (e.g. even before the page cache is consulted)."),
    'field' => array(
      'handler' => 'views_handler_field_boolean',
      'click sortable' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_numeric',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_boolean_operator',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['system']['schema_version'] = array(
    'title' => t('Schema version'),
    'help' => t("The module's database schema version number. -1 if the module is not installed (its tables do not exist); 0 or the largest N of the module's hook_update_N() function that has either been run or existed when the module was first installed."),
    'field' => array(
      'handler' => 'views_handler_field_numeric',
      'click sortable' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_numeric',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  $data['system']['weight'] = array(
    'title' => t('Weight'),
    'help' => t("The order in which this module's hooks should be invoked relative to other modules. Equal-weighted modules are ordered by name."),
    'field' => array(
      'handler' => 'views_handler_field_numeric',
      'click sortable' => TRUE,
    ),
    'argument' => array(
      'handler' => 'views_handler_argument_numeric',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_numeric',
    ),
    'sort' => array(
      'handler' => 'views_handler_sort',
    ),
  );
  //
  $data['system']['info_basetheme'] = array(
    'title' => t('Base theme'),
    'help' => t('The name of the base theme.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_basetheme',
    ),
  );
  $data['system']['info_core'] = array(
    'title' => t('Core'),
    'help' => t('The Drupal core version of the item.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_core',
    ),
  );
  $data['system']['info_datestamp'] = array(
    'title' => t('Date stamp'),
    'help' => t('The date stamp of the project this item belongs to.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_datestamp',
    ),
  );
  $data['system']['info_dependencies'] = array(
    'title' => t('Dependencies'),
    'help' => t('Required modules.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_dependencies',
      'label' => t('Depends on'),
    ),
  );
  $data['system']['info_description'] = array(
    'title' => t('Description'),
    'help' => t('The brief description of the item.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_description',
    ),
  );
  $data['system']['info_engine'] = array(
    'title' => t('Engine'),
    'help' => t('The name of the theme engine; typically: engine = phptemplate.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_engine',
    ),
  );
  $data['system']['info_features'] = array(
    'title' => t('Features'),
    'help' => t('The features of the item.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_features',
    ),
  );
  $data['system']['info_name'] = array(
    'title' => t('Display name'),
    'help' => t('The real name of the item for display purposes; e.g. Node.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_name',
    ),
  );
  $data['system']['info_package'] = array(
    'title' => t('Package'),
    'help' => t('The name of the package this item belongs to.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_package',
    ),
  );
  $data['system']['info_php'] = array(
    'title' => t('PHP'),
    'help' => t('The minimum PHP version of the item.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_php',
    ),
  );
  $data['system']['info_project'] = array(
    'title' => t('Project'),
    'help' => t('The name of the project this item belongs to.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_project',
    ),
  );
  $data['system']['info_regions'] = array(
    'title' => t('Regions'),
    'help' => t('The regions of the theme.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_regions',
    ),
  );
  $data['system']['info_screenshot'] = array(
    'title' => t('Screenshot'),
    'help' => t('The screenshot of the theme.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_screenshot',
    ),
  );
  $data['system']['info_scripts'] = array(
    'title' => t('Scripts'),
    'help' => t('The declared Javascript files of the theme.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_scripts',
    ),
  );
  $data['system']['info_stylesheets'] = array(
    'title' => t('Stylesheets'),
    'help' => t('The declared CSS files of the theme.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_stylesheets',
    ),
  );
  $data['system']['info_version'] = array(
    'title' => t('Version'),
    'help' => t('The version of the item.'),
    'field' => array(
      'handler' => 'views_handler_field_system_info_version',
    ),
  );
  //
  $data['system']['drupal_core'] = array(
    'title' => t('Drupal core'),
    'help' => t('Boolean indicating whether this item is part of Drupal core.'),
    'field' => array(
      'handler' => 'views_handler_field_system_drupal_core',
      'type' => 'yes-no',
    ),
    'filter' => array(
      'handler' => 'views_handler_filter_system_drupal_core',
      'label' => t('Drupal core'),
      'type' => 'yes-no',
    ),
  );

  return $data;
}


/**
 * Implementation of hook_views_handlers().
 */
function views_system_views_handlers() {

  $handlers = array(
    'info' => array(
      'path' => drupal_get_path('module', 'views_system') .'/views/handlers',
    ),
    'handlers' => array(
      'views_handler_filter_system_status' => array(
        'parent' => 'views_handler_filter_boolean_operator',
      ),
      //
      'views_handler_field_system_info_basetheme' => array(
        'parent' => 'views_handler_field',
      ),
      'views_handler_field_system_info_core' => array(
        'parent' => 'views_handler_field',
      ),
      'views_handler_field_system_info_datestamp' => array(
        'parent' => 'views_handler_field_date',
      ),
      'views_handler_field_system_info_dependencies' => array(
        'parent' => 'views_handler_field_prerender_list',
      ),
      'views_handler_field_system_info_description' => array(
        'parent' => 'views_handler_field',
      ),
      'views_handler_field_system_info_engine' => array(
        'parent' => 'views_handler_field',
      ),
      'views_handler_field_system_info_features' => array(
        'parent' => 'views_handler_field_prerender_list',
      ),
      'views_handler_field_system_info_name' => array(
        'parent' => 'views_handler_field',
      ),
      'views_handler_field_system_info_package' => array(
        'parent' => 'views_handler_field',
      ),
      'views_handler_field_system_info_php' => array(
        'parent' => 'views_handler_field',
      ),
      'views_handler_field_system_info_project' => array(
        'parent' => 'views_handler_field',
      ),
      'views_handler_field_system_info_regions' => array(
        'parent' => 'views_handler_field_prerender_list',
      ),
      'views_handler_field_system_info_screenshot' => array(
        'parent' => 'views_handler_field',
      ),
      'views_handler_field_system_info_scripts' => array(
        'parent' => 'views_handler_field_prerender_list',
      ),
      'views_handler_field_system_info_stylesheets' => array(
        'parent' => 'views_handler_field_prerender_list',
      ),
      'views_handler_field_system_info_version' => array(
        'parent' => 'views_handler_field',
      ),
      //
      'views_handler_field_system_drupal_core' => array(
        'parent' => 'views_handler_field_boolean',
      ),
      'views_handler_filter_system_drupal_core' => array(
        'parent' => 'views_handler_filter_boolean_operator',
      ),
    ),
  );

  return $handlers;
}


/**
 * @}
 */
